spannertools.report_format_contributions_of_improper_spanners
=============================================================

.. autofunction:: abjad.tools.spannertools.report_format_contributions_of_improper_spanners.report_format_contributions_of_improper_spanners
   :noindex:
